==> schemacrawler-16.19.1-1.src.tar.gz: SchemaCrawler-16.19.1/schemacrawler-website/src/site/markdown/resources.md <==
# SchemaCrawler Resources

## SchemaCrawler Tutorials

The easiest way to learn how to use the SchemaCrawler command-line is by doing the 
[live online tutorial](https://killercoda.com/schemacrawler). The tutorial works from within 
any browser with no software or plugins needed.


## SchemaCrawler Whitepapers and Documentation

To read more about SchemaCrawler, you can read:

- Thom Snoeren's blog post, [SchemaCrawler 1: Notes & Lint](https://tsn-admin.blogspot.com/2014/12/schemacrawler-1-notes-lint-by-sualeh.html)
- Thom Snoeren's blog post, [SchemaCrawler 2: Database Metadata Discovery](https://tsn-admin.blogspot.com/2015/02/schemacrawler-2-database-metadata.html)
- The SchemaCrawler API [javadocs](apidocs/index.html) .
- Download the [SchemaCrawler
  examples](https://github.com/schemacrawler/SchemaCrawler/releases/)
  for an overview of all SchemaCrawler features and capabilities.
- Read [How to Get Database Metadata as Java POJOs](https://dev.to/sualeh/how-to-get-database-metadata-as-java-pojos-24li), 
  and browse the [javadocs](apidocs/index.html) for an introduction
  to the SchemaCrawler API.


## SchemaCrawler Slides

  <div class="row">
    <div class="col-sm-6 p-3">
      <div class="embed-responsive embed-responsive-16by9">
        <iframe class="embed-responsive-item"  src="https://www.slideshare.net/slideshow/embed_code/8267188" allowfullscreen="true"></iframe>
      </div>
    </div>
    <div class="col-sm-6 p-3">
      <div class="embed-responsive embed-responsive-16by9">
        <iframe src="https://prezi.com/embed/sljesacs5cwd/?bgcolor=ffffff&amp;lock_to_path=0&amp;autoplay=0&amp;autohide_ctrls=0&amp;features=undefined&amp;disabled_features=undefined" allowfullscreen="true"></iframe>
      </div>
    </div>
  </div>
  <div class="row">
    <div class="col-sm-6 p-3">
      <div class="embed-responsive embed-responsive-16by9">
        <iframe src="https://player.vimeo.com/video/102187316" allowfullscreen="true"></iframe>
      </div>
    </div>
    <div class="col-sm-6 p-3">
      <div class="embed-responsive embed-responsive-16by9">
        <iframe src="https://www.youtube.com/embed/zYPfOzImuTk" frameborder="0" allowfullscreen="true"></iframe>
      </div>
    </div>

==> schemacrawler-16.19.11-1.src.tar.gz: SchemaCrawler-16.19.11/schemacrawler-website/src/site/markdown/resources.md <==
# SchemaCrawler Resources

## SchemaCrawler Tutorials

The easiest way to learn how to use the SchemaCrawler command-line is by doing the 
[live online tutorial](https://killercoda.com/schemacrawler). The tutorial works from within 
any browser with no software or plugins needed.


## SchemaCrawler Whitepapers and Documentation

To read more about SchemaCrawler, you can read:

- Thom Snoeren's blog post, [SchemaCrawler 1: Notes & Lint](https://tsn-admin.blogspot.com/2014/12/schemacrawler-1-notes-lint-by-sualeh.html)
- Thom Snoeren's blog post, [SchemaCrawler 2: Database Metadata Discovery](https://tsn-admin.blogspot.com/2015/02/schemacrawler-2-database-metadata.html)
- The SchemaCrawler API [javadocs](https://javadoc.io/doc/us.fatehi/schemacrawler/) .
- Download the [SchemaCrawler
  examples](https://github.com/schemacrawler/SchemaCrawler/releases/)
  for an overview of all SchemaCrawler features and capabilities.
- Read [How to Get Database Metadata as Java POJOs](https://dev.to/sualeh/how-to-get-database-metadata-as-java-pojos-24li), 
  and browse the [javadocs](https://javadoc.io/doc/us.fatehi/schemacrawler/) for an introduction
  to the SchemaCrawler API.


## SchemaCrawler Slides

  <div class="row">
    <div class="col-sm-6 p-3">
      <div class="embed-responsive embed-responsive-16by9">
        <iframe class="embed-responsive-item"  src="https://www.slideshare.net/slideshow/embed_code/8267188" allowfullscreen="true"></iframe>
      </div>
    </div>
    <div class="col-sm-6 p-3">
      <div class="embed-responsive embed-responsive-16by9">
        <iframe src="https://prezi.com/embed/sljesacs5cwd/?bgcolor=ffffff&amp;lock_to_path=0&amp;autoplay=0&amp;autohide_ctrls=0&amp;features=undefined&amp;disabled_features=undefined" allowfullscreen="true"></iframe>
      </div>
    </div>
  </div>
  <div class="row">
    <div class="col-sm-6 p-3">
      <div class="embed-responsive embed-responsive-16by9">
        <iframe src="https://player.vimeo.com/video/102187316" allowfullscreen="true"></iframe>
      </div>
    </div>
    <div class="col-sm-6 p-3">
      <div class="embed-responsive embed-responsive-16by9">
        <iframe src="https://www.youtube.com/embed/zYPfOzImuTk" frameborder="0" allowfullscreen="true"></iframe>
      </div>
    </div>
